<?php
 namespace App\Controller\Frontend; use Symfony\Component\HttpFoundation\Request; use Symfony\Component\HttpFoundation\Response; use Symfony\Component\Form\Form; use Symfony\Component\Form\Extension\Core\Type\SubmitType; use Symfony\Contracts\Translation\TranslatorInterface; use Symfony\Component\Validator\Validator\ValidatorInterface; use Symfony\Component\Validator\ConstraintViolationList; use App\Controller\Controller; use App\Event\EventQueue; use App\Service\Logger; use App\Entity\Site as SiteEntity; use App\Entity\Certificate as CertificateEntity; use App\Entity\NodejsSettings as NodejsSettingsEntity; use App\Entity\PhpSettings as PhpSettingsEntity; use App\Entity\PythonSettings as PythonSettingsEntity; use App\Entity\Database as DatabaseEntity; use App\Entity\DatabaseUser as DatabaseUserEntity; use App\Entity\DatabaseServer as DatabaseServerEntity; use App\Entity\User as UserEntity; use App\Entity\Manager\ConfigManager; use App\Entity\Manager\SiteManager as SiteEntityManager; use App\Entity\Manager\CertificateManager as CertificateEntityManager; use App\Entity\Manager\DatabaseManager as DatabaseEntityManager; use App\Entity\Manager\DatabaseUserManager as DatabaseUserEntityManager; use App\Entity\Manager\DatabaseServerManager as DatabaseServerEntityManager; use App\Entity\Manager\VhostTemplateManager as VhostTemplateEntityManager; use App\Database\Connection as DatabaseConnection; use App\Database\Manager as DatabaseManager; use App\Site\Nginx\Vhost\StaticTemplate as StaticVhostTemplate; use App\Site\Nginx\Vhost\PhpTemplate as PhpVhostTemplate; use App\Site\Nginx\Vhost\PythonTemplate as PythonVhostTemplate; use App\Site\Nginx\Vhost\ReverseProxyTemplate as ReverseProxyVhostTemplate; use App\Site\Nginx\Vhost\Processor\RedirectDomain as RedirectDomainProcessor; use App\Site\Nginx\Vhost\Processor\RedirectServerName as RedirectServerNameProcessor; use App\Site\Nginx\Vhost\Processor\ServerName as ServerNameProcessor; use App\Site\Parser\DomainName as DomainNameParser; use App\Site\Ssl\Generator\RsaKeyGenerator; use App\Site\Creator\NodejsSite as NodejsSiteCreator; use App\Site\Creator\StaticSite as StaticSiteCreator; use App\Site\Creator\PhpSite as PhpSiteCreator; use App\Site\Creator\PythonSite as PythonSiteCreator; use App\Site\Creator\ReverseProxySite as ReverseProxySiteCreator; use App\Site\Ssl\DistinguishedName; use App\Site\Ssl\Generator\CsrGenerator; use App\Site\Ssl\Util\Openssl; use App\Site\NodejsSite; use App\Site\StaticSite; use App\Site\PhpSite; use App\Site\PythonSite; use App\Site\ReverseProxySite; use App\Util\PasswordGenerator; use App\Site\Application\WordPressInstaller; use App\Service\Crypto; class NewSiteController extends Controller { private const WORDPRESS_VHOST_TEMPLATE_NAME = "\127\157\x72\x64\x50\x72\x65\163\x73"; private const NODEJS_VHOST_TEMPLATE_NAME = "\x4e\157\x64\x65\x6a\x73"; private const STATIC_SITE_VHOST_TEMPLATE_NAME = "\123\x74\x61\x74\x69\143"; private const PYTHON_VHOST_TEMPLATE_NAME = "\120\171\x74\150\x6f\x6e"; private const REVERSE_PROXY_VHOST_TEMPLATE_NAME = "\122\x65\166\x65\x72\x73\x65\120\x72\157\170\x79"; private const VARNISH_CACHE_SERVER = "\x31\x32\x37\x2e\60\x2e\x30\x2e\x31\72\66\60\70\61"; private const PASSWORD_LENGTH = 20; private ConfigManager $configManager; private SiteEntityManager $siteEntityManager; private CertificateEntityManager $certificateEntityManager; private DatabaseEntityManager $databaseEntityManager; private DatabaseUserEntityManager $databaseUserEntityManager; private DatabaseServerEntityManager $databaseServerEntityManager; private DomainNameParser $domainNameParser; private VhostTemplateEntityManager $vhostTemplateEntityManager; private ValidatorInterface $validator; private array $wordPressDefaultConfigValues = ["\106\x53\137\x4d\105\x54\x48\x4f\x44" => ["\x76\141\x6c\165\145" => "\144\x69\x72\145\143\164", "\162\141\167" => false], "\x57\120\x5f\104\105\x42\125\x47\x5f\x44\111\x53\x50\x4c\101\x59" => ["\x76\x61\x6c\x75\145" => "\146\141\154\x73\x65", "\x72\141\167" => true], "\127\x50\x5f\104\x45\x42\x55\x47\137\114\117\107" => ["\166\141\154\165\145" => "\x74\x72\165\x65", "\x72\x61\167" => true], "\x43\x4f\116\x43\x41\124\105\x4e\x41\124\x45\137\123\x43\x52\x49\x50\x54\123" => ["\x76\x61\154\165\x65" => "\x66\141\154\x73\145", "\x72\x61\167" => true], "\x41\x55\124\x4f\x53\101\126\x45\137\x49\116\124\x45\x52\126\101\x4c" => ["\166\x61\154\165\145" => 600, "\x72\141\167" => true], "\x57\x50\137\120\117\x53\124\x5f\122\x45\x56\111\x53\111\117\116\123" => ["\x76\141\154\165\x65" => 5, "\x72\141\x77" => true], "\x45\x4d\120\124\x59\x5f\124\x52\x41\x53\110\x5f\104\x41\131\x53" => ["\x76\141\154\165\x65" => 21, "\162\141\167" => true]]; private array $wordPressMultiSiteConfigValues = ["\127\x50\137\x41\114\114\117\x57\x5f\115\125\x4c\x54\111\x53\x49\x54\105" => ["\166\x61\x6c\165\x65" => "\x74\162\x75\x65", "\x72\x61\167" => true], "\115\125\114\x54\111\x53\x49\124\105" => ["\166\141\154\x75\145" => "\x74\x72\x75\145", "\x72\141\x77" => true], "\123\x55\x42\104\117\115\x41\x49\116\x5f\x49\116\x53\x54\101\114\114" => ["\166\141\154\165\145" => "\x66\141\154\x73\145", "\x72\141\167" => true], "\x44\x4f\x4d\x41\111\x4e\x5f\x43\x55\122\x52\105\116\x54\x5f\x53\111\x54\105" => ["\166\141\154\x75\x65" => '', "\162\141\167" => false], "\120\101\x54\110\137\103\x55\x52\122\x45\116\x54\x5f\x53\111\124\x45" => ["\166\x61\x6c\165\145" => "\57", "\x72\141\x77" => false], "\123\x49\x54\x45\137\x49\x44\137\x43\x55\122\122\105\x4e\124\137\123\111\x54\105" => ["\166\x61\154\x75\145" => 1, "\x72\141\x77" => true], "\x42\x4c\x4f\x47\x5f\111\104\x5f\x43\x55\122\122\105\116\x54\137\x53\111\x54\105" => ["\166\x61\154\x75\x65" => 1, "\x72\x61\x77" => true]]; public function __construct(ConfigManager $configManager, SiteEntityManager $siteEntityManager, CertificateEntityManager $certificateEntityManager, DatabaseEntityManager $databaseEntityManager, DatabaseUserEntityManager $databaseUserEntityManager, DatabaseServerEntityManager $databaseServerEntityManager, VhostTemplateEntityManager $vhostTemplateEntityManager, DomainNameParser $domainNameParser, ValidatorInterface $validator, TranslatorInterface $translator, Logger $logger) { goto D39f8; F4c48: $this->siteEntityManager = $siteEntityManager; goto F3956; d8e53: $this->databaseServerEntityManager = $databaseServerEntityManager; goto a1270; d205f: $this->databaseUserEntityManager = $databaseUserEntityManager; goto d8e53; D39f8: $this->configManager = $configManager; goto F4c48; B6cbd: $this->databaseEntityManager = $databaseEntityManager; goto d205f; F64d0: parent::__construct($translator, $logger); goto D11bf; a1270: $this->vhostTemplateEntityManager = $vhostTemplateEntityManager; goto A17f0; Cec03: $this->validator = $validator; goto F64d0; F3956: $this->certificateEntityManager = $certificateEntityManager; goto B6cbd; A17f0: $this->domainNameParser = $domainNameParser; goto Cec03; D11bf: } public function index(Request $request) : Response { goto E6d26; ea0ab: return $response; goto e4f8f; e7a48: E2a08: goto b355b; E6d26: $hasPermissions = $this->hasPermissions(); goto a5b85; Dd019: $response = $this->redirect($this->generateUrl("\143\154\160\137\x73\151\164\145\163")); goto Dd4ec; b355b: $user = $this->getUser(); goto Dd6af; a5b85: if (true === $hasPermissions) { goto E2a08; } goto Dd019; Dd4ec: goto cb3e7; goto e7a48; Dd6af: $response = $this->render("\106\162\157\156\164\145\x6e\144\x2f\123\151\164\x65\57\x4e\145\x77\x2f\x69\x6e\144\x65\x78\x2e\x68\164\x6d\x6c\x2e\164\x77\x69\147", ["\x75\x73\x65\162" => $user]); goto f6d20; f6d20: cb3e7: goto ea0ab; e4f8f: } public function newPythonSite(Request $request) : Response { goto f7dfd; F025a: if (!(true === $request->isMethod("\120\x4f\123\x54"))) { goto C336b; } goto e5d8c; C0d7d: if (!(false === is_null($response))) { goto Bd861; } goto c7976; B9c04: Fe8b1: goto F30de; Fa6b3: if (true === $hasPermissions) { goto Fe8b1; } goto d3d16; d3d16: $response = $this->redirect($this->generateUrl("\143\x6c\160\x5f\x73\151\164\x65\163")); goto ec8e6; D6aae: $response = $this->render("\x46\162\157\156\164\145\x6e\x64\x2f\123\151\164\145\x2f\116\145\x77\57\x70\171\x74\x68\x6f\156\56\x68\x74\x6d\x6c\56\164\167\x69\x67", ["\x75\163\x65\x72" => $user, "\146\x6f\162\155" => $form->createView(), "\x66\157\162\x6d\x45\162\x72\157\x72\x73" => $this->formErrors]); goto c74ea; ba9ff: $response = $this->handleCreatePythonSiteForm($request, $form); goto C0d7d; ec8e6: goto Dedd9; goto B9c04; C3f38: C336b: goto D6aae; A552e: $form = $this->createPythonSiteForm($pythonSettings); goto F025a; D6725: $pythonSettings = new PythonSettingsEntity(); goto A552e; c7976: return $response; goto f8f65; f7dfd: $hasPermissions = $this->hasPermissions(); goto Fa6b3; b766e: if (!(true === $form->isSubmitted())) { goto Abaaa; } goto ba9ff; e5d8c: $form->handleRequest($request); goto b766e; F30de: $user = $this->getUser(); goto D6725; c74ea: Dedd9: goto Ac907; Fcdb6: Abaaa: goto C3f38; f8f65: Bd861: goto Fcdb6; Ac907: return $response; goto E4821; E4821: } private function createPythonSiteForm(PythonSettingsEntity $pythonSettings) : Form { goto Bce3b; Bce3b: $form = $this->createForm("\101\160\160\134\106\157\162\155\x5c\x53\x69\164\x65\x4e\x65\167\x50\x79\164\150\157\x6e\x54\x79\x70\x65", $pythonSettings, ["\141\143\x74\x69\157\156" => $this->generateUrl("\x63\154\x70\x5f\x73\x69\x74\145\x5f\x70\x79\x74\x68\x6f\156\x5f\156\145\167"), "\155\145\x74\150\157\x64" => "\120\117\123\124", "\x61\x74\x74\x72" => ["\x69\144" => "\x6e\145\167\55\160\x79\164\150\x6f\156\55\163\151\164\145\x2d\x66\x6f\x72\x6d"]]); goto B4ccc; dbeaf: return $form; goto Ac7e0; B4ccc: $form->add("\163\165\x62\155\x69\x74", SubmitType::class, ["\x61\x74\x74\162" => ["\143\154\x61\163\x73" => "\x62\x74\x6e\x20\142\x74\156\55\x6c\x67\40\142\x74\x6e\x2d\142\x6c\165\145"], "\x6c\141\142\145\154" => "\x43\x72\x65\141\164\145"]); goto dbeaf; Ac7e0: } private function handleCreatePythonSiteForm(Request $request, Form $form) { goto fab0e; f1aa9: $this->formErrors = $this->getErrorMessages($form); goto e6493; Ea552: Cdebd: goto F7086; D987a: ff8d7: goto c9211; fab0e: if (true === $form->isValid()) { goto Cdebd; } goto f1aa9; F7086: try { goto D6ede; C84a2: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\137\x73\151\164\x65\x73")); goto b3410; D6ede: $session = $request->getSession(); goto b899c; d5cd3: $port = $form->get("\x70\157\x72\164")->getData(); goto c5ea3; C6688: $vhostTemplateName = self::PYTHON_VHOST_TEMPLATE_NAME; goto a4786; f3f7f: throw new \Exception(sprintf("\126\150\157\163\164\x20\164\145\155\160\x6c\141\x74\145\40\42\45\163\x22\40\x6e\x6f\x74\40\146\x6f\x75\x6e\144\56", $vhostTemplateName)); goto A3e62; Ebb5b: $siteUserPassword = $form->get("\x73\151\x74\145\125\163\x65\x72\120\141\x73\x73\x77\157\x72\144")->getData(); goto C6688; b3410: return $response; goto A1067; e5556: $eventData = ["\x73\151\164\x65" => $domainName, "\x73\151\x74\145\125\163\145\x72" => $siteUser, "\x70\171\x74\150\157\156\x56\x65\162\x73\x69\157\x6e" => $pythonVersion, "\x70\x6f\x72\x74" => $port]; goto Ec81f; Ec81f: EventQueue::addEvent(EventQueue::EVENT_SITE_PYTHON_CREATE, $user, $eventData, $request); goto c5df3; c5df3: $session->getFlashBag()->set("\163\165\143\143\x65\163\163", $this->translator->trans("\x53\x69\164\145\x20\x68\141\163\40\x62\x65\x65\156\x20\143\162\x65\x61\164\145\144\56")); goto C84a2; B549d: $this->createPythonSite($domainName, $pythonVersion, $port, $siteUser, $siteUserPassword); goto e5556; Ca37b: $pythonVersion = $form->get("\x70\171\164\x68\x6f\156\126\x65\162\163\151\157\x6e")->getData(); goto d5cd3; a4786: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto B4aa5; Ab87d: $user = $this->getUser(); goto B549d; c5ea3: $siteUser = $form->get("\163\x69\x74\x65\x55\x73\x65\x72")->getData(); goto Ebb5b; B4285: fbb20: goto Ab87d; A3e62: goto e4425; goto B4285; B4aa5: if (false === is_null($vhostTemplateEntity)) { goto fbb20; } goto f3f7f; A1067: e4425: goto Fcb4e; b899c: $domainName = $form->get("\144\x6f\x6d\141\151\156\x4e\x61\x6d\x65")->getData(); goto Ca37b; Fcb4e: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\x61\x6e\x67\x65\x72", $this->translator->trans("\101\156\x20\x65\x72\x72\x6f\x72\40\x68\x61\x73\40\x6f\143\x63\165\162\x72\x65\x64\54\40\x65\x72\x72\x6f\162\x20\155\x65\x73\x73\141\147\145\x3a\x20\x25\x65\x72\162\x6f\162\115\145\x73\163\x61\x67\145\45", ["\x25\x65\162\162\x6f\x72\115\145\x73\163\141\147\x65\x25" => $e->getMessage()])); } goto D987a; e6493: goto ff8d7; goto Ea552; c9211: } public function newReverseProxy(Request $request) : Response { goto F9e78; Fde74: F4823: goto A35c9; Ecc9c: return $response; goto f2515; Ca975: bf5dd: goto E4978; E68b4: $form->handleRequest($request); goto Acfdf; Cd0a2: E6a18: goto Be49d; E4978: $user = $this->getUser(); goto A708b; e26e6: if (true === $hasPermissions) { goto bf5dd; } goto f2267; F2035: if (!(true === $request->isMethod("\x50\117\x53\x54"))) { goto E6a18; } goto E68b4; Efc49: Eb065: goto Ecc9c; f545f: $response = $this->handleReverseProxyForm($request, $form); goto af0ae; Acfdf: if (!(true === $form->isSubmitted())) { goto Cf49e; } goto f545f; A708b: $form = $this->createReverseProxyForm(); goto F2035; fbc84: goto Eb065; goto Ca975; af0ae: if (!(false === is_null($response))) { goto F4823; } goto eb953; f2267: $response = $this->redirect($this->generateUrl("\143\x6c\160\x5f\x73\x69\164\145\x73")); goto fbc84; A35c9: Cf49e: goto Cd0a2; F9e78: $hasPermissions = $this->hasPermissions(); goto e26e6; eb953: return $response; goto Fde74; Be49d: $response = $this->render("\106\162\x6f\x6e\x74\x65\156\x64\x2f\123\x69\x74\x65\57\116\x65\x77\x2f\x72\145\x76\145\x72\163\x65\x2d\x70\x72\x6f\x78\171\x2e\150\164\x6d\154\56\x74\x77\151\147", ["\165\x73\x65\x72" => $user, "\x66\x6f\162\155" => $form->createView(), "\x66\x6f\162\x6d\105\162\162\x6f\162\163" => $this->formErrors]); goto Efc49; f2515: } private function createReverseProxyForm() : Form { goto B6b67; B6b67: $form = $this->createForm("\101\x70\160\134\106\x6f\x72\155\134\123\x69\x74\x65\x4e\145\x77\122\145\166\x65\162\163\x65\x50\162\x6f\x78\x79\x54\x79\160\x65", [], ["\x61\x63\x74\x69\x6f\x6e" => $this->generateUrl("\143\154\x70\137\x73\x69\x74\x65\x5f\x72\145\x76\x65\x72\163\145\x5f\160\162\157\170\171\x5f\x6e\x65\x77"), "\155\145\164\150\157\144" => "\120\x4f\x53\x54", "\x61\164\164\x72" => ["\x69\x64" => "\x6e\x65\167\x2d\x72\145\166\145\x72\163\x65\55\x70\162\157\170\171\55\x66\x6f\x72\x6d"]]); goto fa2f6; fa2f6: $form->add("\163\x75\x62\x6d\x69\164", SubmitType::class, ["\141\x74\164\162" => ["\143\x6c\141\163\x73" => "\142\x74\x6e\x20\142\164\x6e\55\154\x67\40\x62\164\156\x2d\142\154\165\x65"], "\154\141\x62\145\x6c" => "\x43\x72\145\x61\x74\145"]); goto D3c51; D3c51: return $form; goto C0739; C0739: } private function handleReverseProxyForm(Request $request, Form $form) { goto aecb0; bea27: a3900: goto A0854; d707d: F0d94: goto Dddc9; bb269: $this->formErrors = $this->getErrorMessages($form); goto d54b8; d54b8: goto a3900; goto d707d; aecb0: if (true === $form->isValid()) { goto F0d94; } goto bb269; Dddc9: try { goto C8250; A6213: $session->getFlashBag()->set("\163\x75\x63\x63\145\x73\x73", $this->translator->trans("\122\x65\166\x65\x72\163\x65\40\x50\162\x6f\x78\171\40\x68\141\x73\40\142\x65\145\156\40\x63\162\145\x61\164\x65\x64\56")); goto Eb4da; A2178: $siteUserPassword = $form->get("\163\x69\x74\x65\125\x73\x65\x72\120\141\x73\x73\167\x6f\162\144")->getData(); goto f30f0; fea8a: EventQueue::addEvent(EventQueue::EVENT_SITE_REVERSE_PROXY_CREATE, $user, $eventData, $request); goto A6213; a5db7: $this->createReverseProxySite($domainName, $reverseProxyUrl, $siteUser, $siteUserPassword); goto F20b5; cc46f: $domainName = $form->get("\x64\x6f\x6d\x61\x69\156\116\141\x6d\145")->getData(); goto ad9ca; c7df0: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto c5728; D7913: goto a01aa; goto D0328; c0bdd: a01aa: goto d6fd1; C8250: $session = $request->getSession(); goto cc46f; c5728: if (false === is_null($vhostTemplateEntity)) { goto C2020; } goto cb364; ad9ca: $siteUser = $form->get("\x73\x69\164\x65\125\163\145\x72")->getData(); goto A2178; cb364: throw new \Exception(sprintf("\126\x68\x6f\x73\164\x20\x74\145\x6d\160\x6c\141\164\145\x20\42\x25\163\42\40\156\157\x74\40\146\x6f\x75\x6e\144\56", $vhostTemplateName)); goto D7913; Eb4da: $response = $this->redirect($this->generateUrl("\143\x6c\x70\137\x73\151\x74\145\x73")); goto e03ec; Bccd5: $user = $this->getUser(); goto a5db7; e03ec: return $response; goto c0bdd; F20b5: $eventData = ["\x73\151\164\145" => $domainName, "\163\151\x74\145\x55\163\x65\162" => $siteUser, "\x72\x65\x76\145\162\163\145\x50\x72\x6f\170\x79\125\x72\x6c" => $reverseProxyUrl]; goto fea8a; f30f0: $reverseProxyUrl = $form->get("\162\145\x76\x65\x72\x73\145\x50\x72\x6f\x78\x79\x55\162\x6c")->getData(); goto ab41b; D0328: C2020: goto Bccd5; ab41b: $vhostTemplateName = self::REVERSE_PROXY_VHOST_TEMPLATE_NAME; goto c7df0; d6fd1: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\x6e\147\145\x72", $this->translator->trans("\101\x6e\x20\145\162\x72\157\x72\x20\x68\141\x73\40\157\x63\x63\x75\162\x72\145\x64\x2c\x20\x65\x72\x72\157\x72\40\x6d\x65\x73\163\141\147\145\72\x20\45\x65\162\x72\x6f\162\115\145\x73\x73\141\x67\145\x25", ["\x25\x65\x72\x72\x6f\x72\115\145\163\x73\x61\147\145\45" => $e->getMessage()])); } goto bea27; A0854: } public function newNodejsSite(Request $request) : Response { goto e9cb3; fcae5: Ada22: goto b9fe1; Bc003: $form = $this->createNodejsSiteForm($nodejsSettings); goto C9a93; c2472: return $response; goto d2eda; e9cb3: $hasPermissions = $this->hasPermissions(); goto B80d6; Adbd7: d7337: goto fcae5; af89c: $nodejsSettings = new NodejsSettingsEntity(); goto Bc003; d2eda: E2999: goto Adbd7; ef2a0: goto c9380; goto E7f31; c83e0: $response = $this->handleCreateNodejsSiteForm($request, $form); goto be4c8; A502f: $response = $this->redirect($this->generateUrl("\143\x6c\160\x5f\x73\151\x74\x65\x73")); goto ef2a0; B80d6: if (true === $hasPermissions) { goto c0d3e; } goto A502f; d6198: $form->handleRequest($request); goto C2685; de22e: return $response; goto F0d2e; C2685: if (!(true === $form->isSubmitted())) { goto d7337; } goto c83e0; E7f31: c0d3e: goto F29cd; b9fe1: $response = $this->render("\x46\x72\157\x6e\164\145\x6e\x64\57\x53\151\164\x65\x2f\x4e\145\x77\x2f\x6e\157\x64\145\152\x73\x2e\150\164\155\154\x2e\x74\x77\151\x67", ["\165\163\x65\x72" => $user, "\x66\157\162\x6d" => $form->createView(), "\x66\x6f\x72\x6d\105\x72\162\157\162\163" => $this->formErrors]); goto E13c7; E13c7: c9380: goto de22e; C9a93: if (!(true === $request->isMethod("\x50\x4f\x53\x54"))) { goto Ada22; } goto d6198; be4c8: if (!(false === is_null($response))) { goto E2999; } goto c2472; F29cd: $user = $this->getUser(); goto af89c; F0d2e: } private function createNodejsSiteForm(NodejsSettingsEntity $nodejsSettings) : Form { goto Caf44; Ad3e8: return $form; goto f5a87; Bfcd8: $form->add("\x73\165\x62\155\x69\164", SubmitType::class, ["\x61\x74\164\x72" => ["\143\x6c\x61\163\163" => "\142\164\x6e\x20\x62\x74\x6e\55\154\x67\x20\x62\x74\x6e\55\x62\154\x75\145"], "\x6c\141\142\x65\154" => "\x43\162\145\x61\x74\x65"]); goto Ad3e8; Caf44: $form = $this->createForm("\x41\x70\160\x5c\x46\x6f\162\155\134\x53\151\164\145\x4e\x65\167\116\157\x64\145\152\163\124\171\160\x65", $nodejsSettings, ["\x61\143\x74\151\x6f\156" => $this->generateUrl("\x63\154\160\137\x73\151\x74\145\x5f\x6e\x6f\x64\145\152\x73\137\156\x65\x77"), "\x6d\145\x74\150\157\x64" => "\x50\117\123\x54", "\141\x74\x74\162" => ["\151\x64" => "\x6e\145\x77\x2d\156\x6f\x64\x65\x6a\163\x2d\x73\x69\164\145\x2d\x66\x6f\x72\155"]]); goto Bfcd8; f5a87: } private function handleCreateNodejsSiteForm(Request $request, Form $form) { goto b3b15; a986e: e163f: goto e4472; fa61e: goto e163f; goto C7530; C7530: Cd8aa: goto b125d; b3b15: if (true === $form->isValid()) { goto Cd8aa; } goto Ca2dc; b125d: try { goto Eb3ca; Eb3ca: $session = $request->getSession(); goto be088; d44a1: $siteUser = $form->get("\163\151\x74\x65\125\x73\145\x72")->getData(); goto db5e0; Fec5f: $eventData = ["\163\x69\x74\x65" => $domainName, "\163\151\x74\x65\x55\163\x65\x72" => $siteUser, "\x6e\x6f\144\145\x6a\x73\126\145\162\x73\151\x6f\156" => $nodejsVersion, "\160\157\162\164" => $port]; goto B0365; Fd158: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto eaa01; ebd21: $this->createNodejsSite($domainName, $nodejsVersion, $port, $siteUser, $siteUserPassword); goto Fec5f; Cd2ba: $user = $this->getUser(); goto ebd21; eaa01: if (false === is_null($vhostTemplateEntity)) { goto b9684; } goto d17df; B0f2c: $vhostTemplateName = self::NODEJS_VHOST_TEMPLATE_NAME; goto Fd158; C55f6: goto A35e7; goto dd5f8; Eb682: $response = $this->redirect($this->generateUrl("\143\154\x70\137\163\151\164\145\x73")); goto c5e5d; Bc754: $nodejsVersion = $form->get("\156\157\x64\145\x6a\x73\x56\145\x72\x73\x69\x6f\156")->getData(); goto a8654; d17df: throw new \Exception(sprintf("\126\x68\157\x73\x74\x20\164\x65\155\x70\154\x61\x74\145\x20\x22\x25\x73\x22\40\x6e\x6f\x74\40\146\157\165\156\144\x2e", $vhostTemplateName)); goto C55f6; db5e0: $siteUserPassword = $form->get("\163\151\x74\145\x55\163\145\x72\120\141\x73\163\167\157\x72\144")->getData(); goto B0f2c; be088: $domainName = $form->get("\x64\157\x6d\x61\x69\x6e\116\x61\x6d\145")->getData(); goto Bc754; e052e: A35e7: goto a583f; B0365: EventQueue::addEvent(EventQueue::EVENT_SITE_NODEJS_CREATE, $user, $eventData, $request); goto e4eec; dd5f8: b9684: goto Cd2ba; a8654: $port = $form->get("\x70\157\x72\x74")->getData(); goto d44a1; e4eec: $session->getFlashBag()->set("\x73\x75\x63\143\145\x73\163", $this->translator->trans("\x53\x69\x74\x65\x20\150\x61\163\40\142\x65\145\x6e\x20\143\162\145\x61\164\x65\144\56")); goto Eb682; c5e5d: return $response; goto e052e; a583f: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\156\147\x65\162", $this->translator->trans("\x41\x6e\40\145\162\162\157\x72\x20\x68\x61\163\x20\157\143\x63\x75\x72\x72\x65\x64\54\40\x65\162\x72\x6f\162\40\x6d\x65\x73\163\141\x67\x65\x3a\40\45\x65\162\x72\x6f\162\x4d\145\163\x73\x61\x67\145\x25", ["\45\x65\x72\x72\x6f\162\115\x65\163\x73\141\147\x65\45" => $e->getMessage()])); } goto a986e; Ca2dc: $this->formErrors = $this->getErrorMessages($form); goto fa61e; e4472: } public function newStaticSite(Request $request) : Response { goto A0c5e; Ccf57: if (true === $hasPermissions) { goto d6fe7; } goto c5fb4; Ffe10: F2f6d: goto f7d6b; c5fb4: $response = $this->redirect($this->generateUrl("\x63\154\160\x5f\x73\x69\164\145\163")); goto Cc483; E759e: if (!(true === $form->isSubmitted())) { goto e3121; } goto F5a11; e9e5f: $form = $this->createStaticSiteForm(); goto F8b75; f7d6b: $response = $this->render("\x46\x72\157\156\x74\145\x6e\144\57\x53\151\x74\x65\57\116\x65\167\57\x73\164\141\x74\x69\143\x2e\x68\164\155\154\56\x74\x77\x69\147", ["\165\x73\x65\162" => $user, "\146\x6f\162\155" => $form->createView(), "\x66\x6f\162\x6d\x45\x72\162\x6f\x72\163" => $this->formErrors]); goto Bdd4d; Ee66d: return $response; goto b3159; A0c5e: $hasPermissions = $this->hasPermissions(); goto Ccf57; E61fa: return $response; goto Ab5ec; F5a11: $response = $this->handleCreateStaticSiteForm($request, $form); goto Cc197; af3f1: $form->handleRequest($request); goto E759e; Ab5ec: c30fe: goto ccada; ccada: e3121: goto Ffe10; Bdd4d: d5660: goto Ee66d; F8b75: if (!(true === $request->isMethod("\120\x4f\x53\124"))) { goto F2f6d; } goto af3f1; Cc483: goto d5660; goto E1353; Cc197: if (!(false === is_null($response))) { goto c30fe; } goto E61fa; ab8df: $user = $this->getUser(); goto e9e5f; E1353: d6fe7: goto ab8df; b3159: } private function createStaticSiteForm() : Form { goto bfaa2; bfaa2: $form = $this->createForm("\101\x70\x70\x5c\x46\x6f\162\x6d\134\123\x69\x74\145\116\x65\167\x53\164\x61\x74\151\x63\124\x79\160\145", [], ["\x61\x63\164\x69\x6f\x6e" => $this->generateUrl("\x63\x6c\160\137\163\x69\164\145\137\163\164\141\x74\151\143\x5f\x6e\145\167"), "\x6d\x65\x74\150\x6f\144" => "\120\x4f\123\124", "\x61\x74\x74\162" => []]); goto ec445; a184b: return $form; goto de8f8; ec445: $form->add("\163\165\142\155\x69\x74", SubmitType::class, ["\141\164\164\162" => ["\x63\154\x61\163\163" => "\x62\x74\x6e\40\142\164\156\x2d\154\x67\40\142\x74\x6e\x2d\142\154\165\x65"], "\x6c\x61\142\145\154" => "\103\x72\145\141\164\145"]); goto a184b; de8f8: } private function handleCreateStaticSiteForm(Request $request, Form $form) { goto Bc3d7; F3098: $this->formErrors = $this->getErrorMessages($form); goto d09c5; d09c5: goto Ce912; goto C994a; C994a: a468e: goto C3e2c; C3e2c: try { goto f1f0a; Eec49: goto f73c1; goto ce29e; b4245: if (false === is_null($vhostTemplateEntity)) { goto Edd0b; } goto d641c; Fd69e: EventQueue::addEvent(EventQueue::EVENT_SITE_STATIC_CREATE, $user, $eventData, $request); goto a6d1a; ce29e: Edd0b: goto ca73d; de403: $this->createStaticSite($domainName, $siteUser, $siteUserPassword); goto E91f4; Fd0a7: return $response; goto F7ef3; E7029: $siteUser = $form->get("\163\151\x74\145\x55\163\145\162")->getData(); goto F0d88; d641c: throw new \Exception(sprintf("\x56\150\157\163\x74\40\164\x65\x6d\160\154\x61\164\x65\40\42\45\x73\42\40\x6e\x6f\x74\40\x66\x6f\165\x6e\x64\x2e", $vhostTemplateName)); goto Eec49; Cc2b5: $response = $this->redirect($this->generateUrl("\x63\154\x70\137\x73\151\164\145\163")); goto Fd0a7; F0d88: $siteUserPassword = $form->get("\x73\151\x74\145\125\x73\145\x72\x50\141\163\163\167\157\162\x64")->getData(); goto E2949; F7ef3: f73c1: goto d1772; E1591: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto b4245; E2949: $vhostTemplateName = self::STATIC_SITE_VHOST_TEMPLATE_NAME; goto E1591; B1b48: $domainName = $form->get("\144\157\x6d\141\x69\x6e\116\141\x6d\x65")->getData(); goto E7029; a6d1a: $session->getFlashBag()->set("\x73\165\x63\x63\x65\x73\163", $this->translator->trans("\123\151\x74\x65\40\150\141\x73\x20\x62\145\x65\156\x20\x63\162\145\141\x74\x65\144\56")); goto Cc2b5; f1f0a: $session = $request->getSession(); goto B1b48; E91f4: $eventData = ["\x73\x69\x74\145" => $domainName, "\x73\151\164\x65\125\163\145\162" => $siteUser]; goto Fd69e; ca73d: $user = $this->getUser(); goto de403; d1772: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\x61\x6e\147\x65\x72", $this->translator->trans("\101\x6e\x20\145\162\x72\157\162\40\150\141\x73\x20\x6f\143\x63\x75\162\162\145\144\54\40\x65\162\x72\x6f\x72\40\x6d\x65\163\163\141\147\x65\x3a\40\45\x65\x72\162\157\162\x4d\145\x73\163\141\x67\x65\45", ["\45\145\162\162\x6f\162\115\x65\163\163\x61\147\145\x25" => $e->getMessage()])); } goto Df2f8; Bc3d7: if (true === $form->isValid()) { goto a468e; } goto F3098; Df2f8: Ce912: goto d4047; d4047: } public function newPhpSite(Request $request) : Response { goto f242d; f2b60: caf2c: goto bb114; b76dc: c20a3: goto e1400; b00b0: D1135: goto f2b60; f242d: $hasPermissions = $this->hasPermissions(); goto C847c; C847c: if (true === $hasPermissions) { goto c20a3; } goto Bfcbc; Cf4cd: if (!(true === $request->isMethod("\120\117\123\124"))) { goto caf2c; } goto C316d; f5cbb: $form = $this->createPhpSiteForm(); goto Cf4cd; Bbef3: da0c5: goto Caaba; eac59: $response = $this->handleCreatePhpSiteForm($request, $form); goto a098c; Caaba: return $response; goto e5537; e1400: $user = $this->getUser(); goto f5cbb; De5bd: return $response; goto F7c76; a098c: if (!(false === is_null($response))) { goto C5be5; } goto De5bd; E1b11: if (!(true === $form->isSubmitted())) { goto D1135; } goto eac59; C316d: $form->handleRequest($request); goto E1b11; F7c76: C5be5: goto b00b0; Bfcbc: $response = $this->redirect($this->generateUrl("\x63\154\160\x5f\163\x69\164\x65\163")); goto ccf2f; ccf2f: goto da0c5; goto b76dc; bb114: $response = $this->render("\106\162\x6f\156\x74\x65\x6e\144\57\x53\151\164\145\x2f\x4e\x65\x77\x2f\x70\x68\x70\x2e\150\x74\x6d\x6c\56\164\x77\x69\147", ["\x75\163\x65\x72" => $user, "\x66\x6f\162\x6d" => $form->createView(), "\146\157\x72\x6d\x45\x72\162\x6f\x72\x73" => $this->formErrors]); goto Bbef3; e5537: } private function createPhpSiteForm() : Form { goto efa8e; ba033: return $form; goto B4605; C174b: $form->add("\163\x75\142\x6d\x69\164", SubmitType::class, ["\141\164\164\x72" => ["\x63\154\x61\x73\x73" => "\142\164\x6e\40\x62\x74\156\x2d\x6c\147\x20\x62\164\x6e\55\142\154\165\x65"], "\x6c\x61\142\x65\154" => "\103\x72\145\141\x74\x65"]); goto ba033; efa8e: $form = $this->createForm("\101\160\160\134\x46\157\162\x6d\134\x53\151\x74\x65\x4e\145\x77\120\x68\160\124\x79\160\145", [], ["\141\143\x74\151\157\156" => $this->generateUrl("\143\154\x70\x5f\163\151\x74\145\137\160\x68\160\x5f\156\145\167"), "\x6d\145\x74\x68\157\144" => "\120\117\x53\124", "\x61\164\x74\162" => []]); goto C174b; B4605: } private function handleCreatePhpSiteForm(Request $request, Form $form) { goto b5b59; B500f: try { goto F87b1; B240b: ffd78: goto F8ecd; Ec030: EventQueue::addEvent(EventQueue::EVENT_SITE_PHP_CREATE, $user, $eventData, $request); goto A7e29; Ef569: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto F45c0; } goto Be5dc; E0ac1: $rootDirectory = sprintf("\45\x73\x2f\45\163", $rootDirectory, ltrim(rtrim($vhostTemplateEntity->getRootDirectory(), "\x2f"), "\x2f")); goto B240b; A7e29: $session->getFlashBag()->set("\x73\165\143\x63\145\x73\163", $this->translator->trans("\x53\x69\x74\x65\40\150\141\x73\x20\x62\145\145\156\40\143\162\x65\x61\x74\x65\144\56")); goto d7136; A3fee: $user = $this->getUser(); goto F4641; Fa74f: goto ab155; goto aefeb; F4641: $rootDirectory = $domainName; goto B85de; ae674: return $response; goto Ac4e1; B85de: if (!(false === empty($vhostTemplateEntity->getRootDirectory()))) { goto ffd78; } goto E0ac1; F8ecd: $varnishCacheSettings = []; goto Ef569; b47c8: $eventData = ["\163\151\164\x65" => $domainName, "\166\x68\x6f\163\164\124\x65\155\x70\x6c\x61\164\x65\116\141\x6d\145" => $vhostTemplateName, "\x70\150\x70\126\145\x72\x73\x69\x6f\x6e" => $phpVersion, "\163\x69\x74\145\125\163\x65\x72" => $siteUser]; goto Ec030; Be5dc: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto C508a; Add88: $siteUser = $form->get("\x73\151\164\x65\x55\x73\x65\x72")->getData(); goto beca2; D2748: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto E3fab; C508a: F45c0: goto c6178; B0844: throw new \Exception(sprintf("\x56\150\157\163\164\x20\164\x65\x6d\x70\x6c\141\x74\145\x20\x22\45\x73\42\40\156\x6f\164\40\146\x6f\x75\x6e\144\56", $vhostTemplateName)); goto Fa74f; d7136: $response = $this->redirect($this->generateUrl("\143\x6c\x70\x5f\x73\151\x74\145\163")); goto ae674; E3fab: if (false === is_null($vhostTemplateEntity)) { goto E78fc; } goto B0844; beca2: $siteUserPassword = $form->get("\x73\x69\x74\x65\x55\163\x65\162\120\x61\163\x73\167\157\162\x64")->getData(); goto D2748; Ac4e1: ab155: goto B4739; d1102: $domainName = $form->get("\144\x6f\x6d\x61\x69\156\116\141\155\x65")->getData(); goto d5044; D00d3: $vhostTemplateName = $form->get("\x61\x70\160\154\x69\x63\141\x74\151\x6f\156")->getData(); goto d1102; aefeb: E78fc: goto A3fee; c6178: $this->createPhpSite($domainName, $rootDirectory, $phpVersion, $vhostTemplateName, $siteUser, $siteUserPassword, $varnishCacheSettings); goto b47c8; F87b1: $session = $request->getSession(); goto D00d3; d5044: $phpVersion = $form->get("\x70\x68\160\x56\145\x72\x73\151\157\x6e")->getData(); goto Add88; B4739: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\156\147\x65\162", $this->translator->trans("\101\x6e\40\145\162\162\x6f\x72\x20\x68\141\163\x20\157\x63\x63\x75\162\162\145\144\54\40\x65\162\x72\x6f\162\40\x6d\x65\163\163\x61\x67\145\72\40\x25\145\162\162\x6f\x72\115\145\163\163\x61\x67\x65\x25", ["\x25\x65\162\162\x6f\162\115\145\163\163\x61\x67\145\x25" => $e->getMessage()])); } goto Ab870; fc900: goto a3db2; goto c4e02; b5b59: if (true === $form->isValid()) { goto cc40d; } goto c510e; Ab870: a3db2: goto D6450; c4e02: cc40d: goto B500f; c510e: $this->formErrors = $this->getErrorMessages($form); goto fc900; D6450: } public function newWordPressSite(Request $request) : Response { goto a0749; c0aa5: $form = $this->createWordPressSiteForm(); goto d2ddb; bbdde: if (!(true === $form->isSubmitted())) { goto Ae1dd; } goto Ecd50; a8eaa: $response = $this->redirect($this->generateUrl("\143\x6c\160\x5f\x73\x69\164\x65\x73")); goto D9166; c86bb: C8748: goto D7ade; D9166: goto Fa003; goto Cc209; Cc209: c055e: goto F8bed; db2fc: return $response; goto dce62; F8bed: $user = $this->getUser(); goto c0aa5; E254f: if (!(false === is_null($response))) { goto Af9af; } goto d7a08; D7ade: $response = $this->render("\x46\162\x6f\156\164\x65\x6e\x64\x2f\123\x69\164\x65\57\116\145\x77\x2f\x77\157\162\x64\160\x72\x65\x73\x73\56\x68\x74\155\154\56\164\x77\151\147", ["\x75\x73\145\162" => $user, "\146\157\x72\155" => $form->createView(), "\146\x6f\162\x6d\x45\x72\x72\x6f\x72\163" => $this->formErrors]); goto a019e; a3ba2: $form->handleRequest($request); goto bbdde; ba44f: Ae1dd: goto c86bb; Ecd50: $response = $this->handleCreateWordPressSiteForm($request, $form); goto E254f; d2ddb: if (!(true === $request->isMethod("\120\117\123\124"))) { goto C8748; } goto a3ba2; d7a08: return $response; goto cf011; a019e: Fa003: goto db2fc; fce41: if (true === $hasPermissions) { goto c055e; } goto a8eaa; a0749: $hasPermissions = $this->hasPermissions(); goto fce41; cf011: Af9af: goto ba44f; dce62: } private function createWordPressSiteForm() : Form { goto aab02; Ac1ae: return $form; goto Ea815; aab02: $form = $this->createForm("\x41\x70\x70\x5c\x46\157\x72\155\x5c\123\151\x74\x65\x4e\x65\x77\127\157\162\x64\120\x72\145\x73\x73\124\x79\160\145", [], ["\141\x63\x74\x69\157\x6e" => $this->generateUrl("\143\x6c\160\137\163\x69\x74\x65\x5f\x77\157\x72\x64\160\162\x65\x73\163\137\156\x65\167"), "\155\145\164\x68\157\x64" => "\x50\117\x53\x54", "\x61\x74\164\x72" => ["\x69\144" => "\156\x65\167\x2d\167\157\162\144\160\162\x65\163\163\55\x73\151\164\145\55\146\x6f\x72\155"]]); goto ad531; ad531: $form->add("\x73\165\x62\x6d\151\x74", SubmitType::class, ["\x61\x74\x74\x72" => ["\x63\x6c\141\163\x73" => "\x62\164\156\x20\142\x74\156\x2d\x6c\147\x20\x62\164\x6e\55\x62\154\165\145"], "\154\x61\x62\145\x6c" => "\x43\162\x65\x61\164\145"]); goto Ac1ae; Ea815: } private function handleCreateWordPressSiteForm(Request $request, Form $form) { goto Bf9db; Be750: try { goto de7a9; f8f84: $this->installWordPress($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail, $siteEntity, $activeDatabaseServerEntity, $databaseEntity, $databaseUserEntity); goto b8c81; a137d: $title = $form->get("\163\x69\x74\x65\x54\x69\x74\x6c\x65")->getData(); goto c22e7; F64f3: $databaseUserName = $this->getUniqueDatabaseUserName($generatedName); goto A8c58; E3cc8: $adminPassword = $form->get("\141\144\x6d\x69\156\120\x61\163\x73\167\157\x72\x64")->getData(); goto A5558; fc3c6: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto f42c3; A5558: $adminEmail = $form->get("\x61\x64\155\x69\x6e\x45\x6d\x61\151\x6c")->getData(); goto B9b74; Fa6a9: $siteCredentials["\x57\157\x72\144\120\162\145\163\x73"] = [$this->translator->trans("\x41\x64\155\151\156\40\105\x2d\115\x61\x69\154") => $adminEmail, $this->translator->trans("\x41\144\155\151\156\40\125\163\145\162\40\x4e\141\155\x65") => $adminUserName, $this->translator->trans("\101\x64\x6d\151\156\x20\120\x61\x73\163\167\157\162\x64") => $adminPassword, $this->translator->trans("\101\x64\155\x69\156\40\x55\162\154") => sprintf("\150\x74\164\x70\x73\72\x2f\x2f\45\163\57\167\x70\x2d\141\144\155\151\x6e\57", rtrim($domainName, "\57"))]; goto f2b02; fb9d1: $session->set("\x73\151\164\x65\103\162\145\x64\145\x6e\164\151\x61\x6c\x73", $siteCredentials); goto b7813; Fe05e: $databaseManager->createUser($databaseUserEntity); goto D03c7; Af47f: if (!(false === is_null($siteEntity))) { goto Fc1f5; } goto D093b; c22e7: $adminUserName = $form->get("\141\x64\155\151\156\x55\163\145\x72\x4e\141\155\x65")->getData(); goto E3cc8; Df845: $varnishCacheSettings = []; goto e35f9; C0288: $databaseUserEntity = $this->databaseUserEntityManager->createEntity(); goto b022a; b7813: $eventData = ["\163\151\x74\x65" => $domainName, "\163\151\164\x65\125\163\145\x72" => $siteUser]; goto B12f0; b6fde: Be8ca: goto c6714; D5b53: $databaseEntity->setSite($siteEntity); goto C0288; A751f: $databaseEntity = $this->databaseEntityManager->createEntity(); goto f9e98; Dc630: $databaseManager->createDatabase($databaseEntity); goto Fe05e; fee7d: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto b6fde; A8c58: $databaseUserPassword = PasswordGenerator::generate(self::PASSWORD_LENGTH); goto B0f01; B12f0: EventQueue::addEvent(EventQueue::EVENT_SITE_WORDPRESS_CREATE, $user, $eventData, $request); goto A6f14; F8649: $siteUserPassword = $form->get("\x73\x69\164\x65\125\x73\x65\162\120\x61\163\x73\x77\157\x72\144")->getData(); goto cf569; Ccc6d: $databaseUserEntity->setPassword(Crypto::encrypt($databaseUserPassword)); goto f2b24; b022a: $databaseUserEntity->setUserName($databaseUserName); goto Ccc6d; B0f01: $url = sprintf("\150\164\164\x70\x73\72\x2f\57\45\163", $siteEntity->getDomainName()); goto a137d; ba917: $databaseEntity->setName($databaseName); goto D5b53; c8909: $session = $request->getSession(); goto e7471; f42c3: $instance = $request->attributes->get("\x69\x6e\x73\x74\x61\x6e\143\x65"); goto Caa76; f2b24: $databaseUserEntity->setPermissions(DatabaseUserEntity::PERMISSIONS_READ_WRITE); goto fc299; e35f9: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto Be8ca; } goto fee7d; Caa76: $siteCredentials = [$this->translator->trans("\123\x69\x74\x65") => [$this->translator->trans("\x49\120\40\101\x64\144\162\x65\163\163") => $instance->getIpv4PublicIp(), $this->translator->trans("\104\157\155\141\x69\x6e\x20\116\141\x6d\145") => sprintf("\x68\x74\164\x70\x73\x3a\57\x2f\x25\x73", $domainName), $this->translator->trans("\x53\151\x74\145\x20\125\163\145\x72") => $siteUser, $this->translator->trans("\x50\141\x73\x73\167\x6f\162\x64") => $siteUserPassword]]; goto Af47f; D12c1: $phpVersion = $vhostTemplateEntity->getPhpVersion(); goto Df845; fef0b: $databaseManager = new DatabaseManager($activeDatabaseServerEntity); goto Dc630; d9c38: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto A751f; c6714: $siteEntity = $this->createPhpSite($domainName, $domainName, $phpVersion, self::WORDPRESS_VHOST_TEMPLATE_NAME, $siteUser, $siteUserPassword, $varnishCacheSettings); goto fc3c6; de7a9: $user = $this->getUser(); goto c8909; cf569: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::WORDPRESS_VHOST_TEMPLATE_NAME); goto D12c1; b8c81: $siteCredentials[$this->translator->trans("\x44\x61\164\x61\x62\x61\163\145")] = [$this->translator->trans("\110\157\163\x74") => $activeDatabaseServerEntity->getHost(), $this->translator->trans("\120\x6f\162\x74") => $activeDatabaseServerEntity->getPort(), $this->translator->trans("\104\141\164\141\x62\141\x73\x65\40\116\x61\x6d\145") => $databaseName, $this->translator->trans("\x44\141\164\x61\142\141\x73\145\x20\125\x73\145\x72\x20\x4e\x61\x6d\145") => $databaseUserName, $this->translator->trans("\x44\141\164\x61\142\x61\x73\x65\x20\x55\163\x65\x72\40\120\141\x73\x73\167\157\x72\144") => $databaseUserPassword]; goto Fa6a9; bb947: $generatedName = $this->generateNameFromDomainName($domainName); goto a0b46; Cbcfd: return $response; goto f18f7; A6f14: $response = $this->redirect($this->generateUrl("\x63\154\x70\x5f\163\151\x74\145\x5f\167\157\x72\x64\x70\x72\145\x73\x73\x5f\151\156\x73\164\141\x6c\154\x65\x64")); goto Cbcfd; f2b02: Fc1f5: goto fb9d1; c094b: $databaseEntity->addUser($databaseUserEntity); goto Dd0e0; Dd0e0: $siteEntity->addDatabase($databaseEntity); goto fef0b; f9e98: $databaseEntity->setDatabaseServer($activeDatabaseServerEntity); goto ba917; D03c7: $this->siteEntityManager->updateEntity($siteEntity); goto f8f84; a0b46: $siteUser = $form->get("\163\151\164\x65\x55\x73\145\x72")->getData(); goto F8649; D093b: $databaseName = $this->getUniqueDatabaseName($generatedName); goto F64f3; B9b74: $isMultiSite = $form->get("\x6d\165\x6c\x74\x69\123\151\x74\x65")->getData(); goto d9c38; fc299: $databaseUserEntity->setDatabase($databaseEntity); goto c094b; e7471: $domainName = $form->get("\144\157\155\x61\151\156\116\141\155\145")->getData(); goto bb947; f18f7: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\x61\x6e\x67\145\162", $this->translator->trans("\x41\x6e\x20\x65\162\x72\157\162\40\x68\x61\163\40\x6f\x63\x63\165\x72\x72\145\144\x2c\40\x65\x72\162\x6f\x72\40\x6d\145\x73\x73\x61\x67\x65\72\40\45\145\162\162\x6f\162\x4d\145\x73\x73\x61\x67\145\45", ["\45\145\x72\x72\157\162\115\145\163\x73\x61\x67\x65\x25" => $e->getMessage()])); } goto Ddd76; Ff8a7: D6801: goto Be750; b3cab: $this->formErrors = $this->getErrorMessages($form); goto Ceabe; Ddd76: a0b6b: goto Aa893; Bf9db: if (true === $form->isValid()) { goto D6801; } goto b3cab; Ceabe: goto a0b6b; goto Ff8a7; Aa893: } private function installWordPress(bool $isMultiSite, string $url, string $title, string $adminUserName, string $adminPassword, string $adminEmail, SiteEntity $siteEntity, DatabaseServerEntity $databaseServerEntity, DatabaseEntity $databaseEntity, DatabaseUserEntity $databaseUserEntity) : void { goto Bee96; C0ed2: $wordPressInstaller->installCore($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail); goto Bd47a; B2ceb: $databaseUserName = $databaseUserEntity->getUserName(); goto E0f8b; d1677: if (!(true === $isMultiSite)) { goto e8d23; } goto F03b1; C62f5: foreach ($this->wordPressMultiSiteConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\x76\141\x6c\165\x65"], $config["\x72\x61\x77"]); A514b: } goto F06f3; Bd47a: foreach ($this->wordPressDefaultConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\x76\x61\x6c\165\145"], $config["\x72\x61\x77"]); a5520: } goto B5a4e; Bee96: $databaseHost = sprintf("\45\163\72\x25\x73", $databaseServerEntity->getHost(), $databaseServerEntity->getPort()); goto ba7a5; E0f8b: $databaseUserPassword = Crypto::decrypt($databaseUserEntity->getPassword()); goto D202c; F03b1: $this->wordPressMultiSiteConfigValues["\x44\117\115\101\x49\116\x5f\x43\125\122\x52\105\116\x54\x5f\123\x49\124\105"]["\166\141\154\x75\x65"] = $siteEntity->getDomainName(); goto C62f5; Eece9: $wordPressInstaller->createConfig($databaseHost, $databaseName, $databaseUserName, $databaseUserPassword); goto C0ed2; d6687: e8d23: goto c280b; c280b: $wordPressInstaller->resetPermissions(); goto cd66b; Cfbdc: $wordPressInstaller->downloadAndExtractLatestVersion(); goto Eece9; F06f3: A5556: goto d6687; ba7a5: $databaseName = $databaseEntity->getName(); goto B2ceb; B5a4e: afd8e: goto d1677; D202c: $wordPressInstaller = new WordPressInstaller($siteEntity); goto Cfbdc; cd66b: } private function createPhpSite(string $domainName, string $rootDirectory, string $phpVersion, string $vhostTemplateName, string $siteUser, string $siteUserPassword, array $varnishCacheSettings = []) : SiteEntity { goto a72ef; cdea1: F1121: goto Bf1d9; D4a7e: $phpSite = new PhpSite(); goto e49c5; a854d: a78b4: goto fa14e; Ec871: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto ac693; d530c: $subjectAlternativeNames[] = sprintf("\167\x77\x77\56\x25\163", $domainName); goto a353b; D754b: ae846: goto Ecdfe; b3928: if (!(false === empty($redirectionVhostTemplate))) { goto a78b4; } goto C1709; Ac153: $rsaKeyGenerator = new RsaKeyGenerator(); goto Acd66; e54e4: $constraintViolationList->addAll($phpSettingsConstraints); goto F2f5a; cc832: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\56\57\x2e\56\x2f\56\56\x2f\162\x65\163\x6f\165\x72\143\145\x73\x2f\x6e\147\x69\x6e\170\57\x76\x68\x6f\x73\164\x5f\164\145\x6d\x70\x6c\x61\164\x65\57\x72\x65\144\x69\x72\x65\x63\164\55\150\164\164\x70\x33"); goto D754b; E6b73: $phpSite->setUserPassword($siteEntity->getUserPassword()); goto d1899; a05b7: $certificateEntity->setCsr($csr); goto Dfb29; f07d1: $defaultVarnishCacheSettings = ["\145\x6e\141\142\154\x65\x64" => false, "\x73\x65\x72\x76\x65\162" => self::VARNISH_CACHE_SERVER, "\x63\141\143\150\145\x54\x61\x67\120\162\145\x66\151\170" => substr(md5(time()), 0, 4)]; goto Ddbe8; F2f5a: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto e2d38; E942e: $phpSiteCreator->createUser(); goto F4cb5; E792f: $phpSettingsEntity->setPhpVersion($phpVersion); goto Af368; d1899: $phpSite->setDomainName($domainName); goto ba62e; fa14e: a45ae: goto a4950; f635d: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto Cf3b4; fe417: goto ae846; goto ef7f9; f0764: if (!(false === is_null($subdomain) && "\x77\x77\x77" == $subdomain)) { goto de787; } goto c7913; e44b9: $siteEntity->setUserPassword($siteUserPassword); goto a17e5; eedb2: $phpSite->setCertificate($certificateEntity); goto eba00; fb6c2: $phpSite->setVarnishCacheSettings($varnishCacheSettings); goto Cbf87; a17e5: $siteEntity->setRootDirectory($rootDirectory); goto ca745; E6c23: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto d41fc; bf836: $phpSiteCreator->createPrivateKeyAndCertificate(); goto C33eb; Bf1d9: if (!(true === is_null($subdomain) || "\167\x77\167" == $subdomain)) { goto a45ae; } goto d7e04; a353b: C8d1a: goto f0764; Bf6e3: $siteEntity->setPhpSettings($phpSettingsEntity); goto E792f; a4950: $siteEntity->setVhostTemplate($vhostTemplate); goto e8442; B6e72: $phpSiteCreator->reloadNginxService(); goto D8c2d; Ce549: $phpSiteCreator->createLogrotateFile(); goto a87c1; F707f: $siteEntity->setCertificate($certificateEntity); goto D4a7e; C33eb: $phpSiteCreator->createPhpFpmPool(); goto f2585; c7913: $subjectAlternativeNames[] = $registrableDomain; goto C0ee4; f2585: $phpSiteCreator->reloadPhpFpmService(); goto bde2f; a4fd9: $vhostTemplate = new PhpVhostTemplate($phpSite); goto e656b; B7385: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto ed6cf; Cbf87: ab55f: goto Aeb37; C1709: $vhostTemplate = sprintf("\45\163\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto a854d; E7122: $siteEntity->setUser($siteUser); goto e44b9; C0ee4: de787: goto fe7ab; A81c8: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto dfd06; Eec5b: $csr = $csrGenerator->generate(); goto f635d; A858e: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto B7385; e7b74: $phpSettingsConstraints = $this->validator->validate($phpSettingsEntity); goto bb144; e8255: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Ec871; D699d: $certificateEntity->setSite($siteEntity); goto Ac153; D976b: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\x2e\x2f\x2e\56\x2f\x2e\56\57\x72\x65\163\x6f\165\162\143\x65\163\57\x6e\147\x69\156\x78\x2f\x76\x68\157\163\x74\x5f\164\x65\x6d\x70\154\141\164\x65\x2f\162\145\144\151\162\x65\x63\x74"); goto fe417; C8d06: $certificateEntity->setCertificate($selfSignedCertificate); goto F707f; Aeb37: $phpSiteCreator->createNginxVhost(); goto B6e72; Acd66: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto A058f; A25c0: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto Eec5b; b78f8: $siteEntity->setType(SiteEntity::TYPE_PHP); goto Fb113; cd51c: $phpSite->setRootDirectory($siteEntity->getRootDirectory()); goto eedb2; a72ef: $varnishCache = false === empty($varnishCacheSettings) ? true : false; goto c4d40; a3556: if (!(true === is_null($subdomain))) { goto C8d1a; } goto d530c; ac693: $siteEntity = $this->siteEntityManager->createEntity(); goto b78f8; d0c72: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto a05b7; a97f1: $certificateEntity = $this->certificateEntityManager->createEntity(); goto D699d; C40b5: $siteConstraints = $this->validator->validate($siteEntity); goto e7b74; e49c5: $phpSite->setUser($siteEntity->getUser()); goto E6b73; B0487: A0454: goto a97f1; bd074: $vhostTemplate->resetProcessors(); goto A858e; A1cb4: $this->siteEntityManager->updateEntity($siteEntity); goto c6ee1; fe7ab: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto A25c0; a87c1: $phpSiteCreator->createIndexPhp(); goto bf836; Dfb29: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto C8d06; ffec9: $siteEntity->setVarnishCache(true); goto cdea1; e2d38: throw new \Exception(implode("\x3b\x20", $errorMessages)); goto B0487; Af368: $phpSettingsEntity->setSite($siteEntity); goto C40b5; D8e29: $subdomain = false === empty($subdomain) ? $subdomain : null; goto e8255; c6ee1: return $siteEntity; goto c6919; F383c: $vhostTemplate->build(); goto E6c23; ed6cf: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto F383c; Ecdfe: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto b3928; Dda48: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto A81c8; d41fc: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto A1cb4; ba62e: $phpSite->setRegistrableDomain($registrableDomain); goto cb223; d7e04: if (true === isset($_ENV["\101\120\120\x5f\x48\x54\x54\x50\63"]) && "\x74\x72\x75\x65" === $_ENV["\x41\x50\120\137\x48\x54\x54\x50\x33"]) { goto ca066; } goto D976b; Ddbe8: $varnishCacheSettings = array_merge($defaultVarnishCacheSettings, $varnishCacheSettings); goto D5e99; A058f: $subjectAlternativeNames = []; goto a3556; D5e99: $phpSiteCreator->createVarnishCacheStructure($varnishCacheSettings); goto fb6c2; a8c3f: $phpSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto B0e23; Fb113: $siteEntity->setDomainName($domainName); goto E7122; bb144: if (!(count($siteConstraints) || count($phpSettingsConstraints))) { goto A0454; } goto Ece1d; F4cb5: $phpSiteCreator->createRootDirectory(); goto Ce549; Cf3b4: $certificateEntity->setDefaultCertificate(true); goto d0c72; e656b: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto bd074; Ece1d: $constraintViolationList = new ConstraintViolationList(); goto Afac4; ca745: if (!(false === empty($varnishCache))) { goto F1121; } goto ffec9; cd9de: $phpSite->setVarnishCache(true); goto f07d1; bde2f: if (!(true === $varnishCache)) { goto ab55f; } goto cd9de; eba00: $phpSite->setPhpSettings($phpSettingsEntity); goto a8c3f; dfd06: $subdomain = $resolvedDomainName->subDomain()->toString(); goto D8e29; Afac4: $constraintViolationList->addAll($siteConstraints); goto e54e4; cb223: $phpSite->setSubdomain($subdomain); goto cd51c; B0e23: $phpSiteCreator = new PhpSiteCreator($phpSite); goto E942e; D8c2d: $phpSiteCreator->resetPermissions(); goto a4fd9; c4d40: $rootDirectory = trim(rtrim(ltrim($rootDirectory, "\x2f")), "\x2f"); goto Dda48; ef7f9: ca066: goto cc832; e8442: $phpSettingsEntity = new PhpSettingsEntity(); goto Bf6e3; c6919: } private function createNodejsSite(string $domainName, string $nodejsVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto bcbaa; Dcefb: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\56\x2f\56\56\x2f\56\x2e\x2f\162\145\x73\157\x75\x72\x63\145\x73\x2f\156\x67\x69\x6e\170\57\166\x68\x6f\163\x74\x5f\x74\x65\155\160\x6c\141\x74\x65\x2f\162\145\x64\151\162\145\x63\x74\55\150\x74\164\160\x33"); goto E74a3; Cea7c: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto Bb5e2; f6c07: $nodejsSettingsEntity = new NodejsSettingsEntity(); goto dc991; cde45: $nodejsSiteCreator->installNodejs(); goto f1456; df5eb: $subdomain = false === empty($subdomain) ? $subdomain : null; goto D2159; b8b81: $constraintViolationList->addAll($siteConstraints); goto b1bab; a189d: $siteEntity->setUser($siteUser); goto b6f6f; a1e26: if (!(false === is_null($subdomain) && "\x77\x77\167" == $subdomain)) { goto Ed9b0; } goto E4b21; Bb5e2: throw new \Exception(implode("\73\x20", $errorMessages)); goto e2cfc; d224a: $subjectAlternativeNames = []; goto F7be8; E4b21: $subjectAlternativeNames[] = $registrableDomain; goto a0191; C3c4f: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto E01cb; E4b0b: $nodejsSite->setNodejsSettings($nodejsSettingsEntity); goto f4562; Dbc76: $nodejsSettingsConstraints = $this->validator->validate($nodejsSettingsEntity); goto E22c1; Fc83c: $nodejsSite->setRootDirectory($siteEntity->getRootDirectory()); goto ec6a3; a753a: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto Ff48c; a0191: Ed9b0: goto cdb5f; cdb5f: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto Ab6d8; E2f64: if (true === isset($_ENV["\101\120\120\x5f\110\124\124\x50\x33"]) && "\x74\x72\x75\145" === $_ENV["\x41\x50\120\x5f\x48\x54\124\120\63"]) { goto fd462; } goto Aef0a; e2c21: $nodejsSite->setUser($siteEntity->getUser()); goto e48e5; ec6a3: $nodejsSite->setCertificate($certificateEntity); goto E4b0b; a943e: $csr = $csrGenerator->generate(); goto F3e4b; C106d: $certificateEntity->setDefaultCertificate(true); goto ea80c; f1456: $nodejsSiteCreator->createPrivateKeyAndCertificate(); goto b8c3d; E74a3: Ad8be: goto Ca1bf; Ae618: ef4f4: goto Fa024; acf4b: $nodejsSettingsEntity->setNodejsVersion($nodejsVersion); goto fb680; e0b9d: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto Be975; D2159: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::NODEJS_VHOST_TEMPLATE_NAME); goto C3c4f; d6faf: $vhostTemplate = new StaticVhostTemplate($nodejsSite); goto Ad4ca; D9e41: $nodejsSite->setDomainName($domainName); goto ea110; f4562: $nodejsSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto D4b31; cbf57: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto e0b9d; d871f: $vhostTemplate->build(); goto Ac57e; bcbaa: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto a753a; Ad4ca: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto ce21f; b6f6f: $siteEntity->setUserPassword($siteUserPassword); goto f850a; Fa024: $siteEntity->setVhostTemplate($vhostTemplate); goto f6c07; C6243: $certificateEntity->setCsr($csr); goto D1aa9; E01cb: $siteEntity = $this->siteEntityManager->createEntity(); goto D4ff0; Ac57e: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto Edb13; Be975: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto d871f; Ebf05: $subjectAlternativeNames[] = sprintf("\x77\167\167\56\45\163", $domainName); goto F11f8; Ca1bf: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto B779f; B641f: f5219: goto Ae618; E5d4e: $certificateEntity->setSite($siteEntity); goto E1fcd; Edb13: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto a07c7; D4b31: $nodejsSiteCreator = new NodejsSiteCreator($nodejsSite); goto Fb550; F2910: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto d224a; Da9bb: $siteConstraints = $this->validator->validate($siteEntity); goto Dbc76; ce21f: $vhostTemplate->resetProcessors(); goto cbf57; a07c7: $this->siteEntityManager->updateEntity($siteEntity); goto A0da6; F7be8: if (!(true === is_null($subdomain))) { goto B63b6; } goto Ebf05; D1aa9: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto f124b; f124b: $certificateEntity->setCertificate($selfSignedCertificate); goto C3107; b1bab: $constraintViolationList->addAll($nodejsSettingsConstraints); goto Cea7c; Cb326: goto Ad8be; goto dbc1b; E1fcd: $rsaKeyGenerator = new RsaKeyGenerator(); goto F2910; dbc1b: fd462: goto Dcefb; C3107: $siteEntity->setCertificate($certificateEntity); goto c2c53; Ff48c: $subdomain = $resolvedDomainName->subDomain()->toString(); goto df5eb; e48e5: $nodejsSite->setUserPassword($siteEntity->getUserPassword()); goto D9e41; F11f8: B63b6: goto a1e26; C97af: $nodejsSiteCreator->createNvmDirectory(); goto cde45; A9448: $nodejsSite->setSubdomain($subdomain); goto Fc83c; E22c1: if (!(count($siteConstraints) || count($nodejsSettingsConstraints))) { goto Ed19b; } goto Fa970; Aef0a: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\57\x2e\56\57\56\56\57\162\x65\x73\157\165\162\x63\x65\x73\57\156\x67\x69\156\x78\57\166\x68\157\163\x74\x5f\164\x65\155\x70\x6c\x61\164\x65\57\x72\145\144\151\162\x65\143\x74"); goto Cb326; ea110: $nodejsSite->setRegistrableDomain($registrableDomain); goto A9448; fb680: $nodejsSettingsEntity->setPort($port); goto f5ff9; f5ff9: $nodejsSettingsEntity->setSite($siteEntity); goto Da9bb; dc991: $siteEntity->setNodejsSettings($nodejsSettingsEntity); goto acf4b; f56ef: $nodejsSiteCreator->resetPermissions(); goto d6faf; A9665: $nodejsSiteCreator->reloadNginxService(); goto f56ef; f62a9: $nodejsSiteCreator->createLogrotateFile(); goto C97af; e2cfc: Ed19b: goto c13b9; Ab6d8: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto a943e; A0da6: return $siteEntity; goto b1930; Fa970: $constraintViolationList = new ConstraintViolationList(); goto b8b81; Fb550: $nodejsSiteCreator->createUser(); goto cfe4e; F3e4b: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto C106d; c13b9: $certificateEntity = $this->certificateEntityManager->createEntity(); goto E5d4e; aa3c4: $vhostTemplate = sprintf("\45\163\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto B641f; B779f: if (!(false === empty($redirectionVhostTemplate))) { goto f5219; } goto aa3c4; ea80c: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto C6243; D4ff0: $siteEntity->setType(SiteEntity::TYPE_NODEJS); goto D7cdb; f850a: $siteEntity->setRootDirectory($domainName); goto b0ba9; b0ba9: if (!(true === is_null($subdomain) || "\167\167\x77" == $subdomain)) { goto ef4f4; } goto E2f64; b8c3d: $nodejsSiteCreator->createNginxVhost(); goto A9665; c2c53: $nodejsSite = new NodejsSite(); goto e2c21; D7cdb: $siteEntity->setDomainName($domainName); goto a189d; cfe4e: $nodejsSiteCreator->createRootDirectory(); goto f62a9; b1930: } private function createPythonSite(string $domainName, string $pythonVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto C34cd; deaff: $pythonSiteCreator->createLogrotateFile(); goto bac04; d2e16: $certificateEntity->setCsr($csr); goto b7756; dec9d: $certificateEntity->setCertificate($selfSignedCertificate); goto fcd99; e6f0e: $vhostTemplate->resetProcessors(); goto Cafa3; cfbfb: if (!(count($siteConstraints) || count($pythonSettingsConstraints))) { goto Fb695; } goto F7f49; d576d: $pythonSettingsEntity->setPort($port); goto Da155; f5f5b: $pythonSettingsEntity = new PythonSettingsEntity(); goto Cf2d9; Bec4f: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto D8100; C34cd: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto Bc36a; C6e1f: if (!(false === empty($redirectionVhostTemplate))) { goto e371b; } goto E5263; Eafb8: $constraintViolationList->addAll($pythonSettingsConstraints); goto d02d7; fa1ef: $certificateEntity->setDefaultCertificate(true); goto Ee6e8; b43f0: $subjectAlternativeNames[] = $registrableDomain; goto ed485; B224b: c1971: goto d90e6; ed058: $siteEntity->setType(SiteEntity::TYPE_PYTHON); goto fc89f; D2689: $constraintViolationList->addAll($siteConstraints); goto Eafb8; d1fbb: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::PYTHON_VHOST_TEMPLATE_NAME); goto C947e; a5d39: $subdomain = $resolvedDomainName->subDomain()->toString(); goto dbc9e; Fcbfc: $pythonSite->setPythonSettings($pythonSettingsEntity); goto d6c7c; C947e: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto f6e41; Bd4a4: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto f2b82; A40c4: e51ef: goto c24be; Ba4f8: F9c80: goto E6f6b; D1f2a: $pythonSettingsConstraints = $this->validator->validate($pythonSettingsEntity); goto cfbfb; f3ca9: $rsaKeyGenerator = new RsaKeyGenerator(); goto dd6f4; f2b82: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto f846d; E7dfa: if (!(true === is_null($subdomain))) { goto e51ef; } goto f9ff8; A3fd6: $vhostTemplate = new PythonVhostTemplate($pythonSite); goto B19d9; b0737: Fb695: goto c6084; d9d90: $siteConstraints = $this->validator->validate($siteEntity); goto D1f2a; E5263: $vhostTemplate = sprintf("\45\x73\x25\x73", $redirectionVhostTemplate, $vhostTemplate); goto d8a89; ea81d: $siteEntity->setRootDirectory($domainName); goto fe038; Fe9cf: $pythonSiteCreator->createRootDirectory(); goto deaff; c24be: if (!(false === is_null($subdomain) && "\x77\167\x77" == $subdomain)) { goto ccfa9; } goto b43f0; D8cc6: $this->siteEntityManager->updateEntity($siteEntity); goto Ac2a8; f9ff8: $subjectAlternativeNames[] = sprintf("\167\x77\167\x2e\x25\x73", $domainName); goto A40c4; d90e6: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\x2e\57\x2e\56\57\56\56\x2f\162\x65\x73\157\165\162\x63\x65\x73\x2f\x6e\147\x69\156\170\57\166\x68\x6f\163\164\137\x74\145\155\160\154\x61\164\x65\57\x72\145\144\x69\x72\x65\x63\x74\55\x68\164\164\x70\63"); goto A8e52; dd6f4: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto daaf5; d8a89: e371b: goto Ba4f8; F3984: throw new \Exception(implode("\x3b\40", $errorMessages)); goto b0737; af441: $pythonSiteCreator->createPrivateKeyAndCertificate(); goto A7386; e4623: $siteEntity->setUserPassword($siteUserPassword); goto ea81d; bbcaa: $pythonSiteCreator->reloadNginxService(); goto B80b0; E2c40: $pythonSite->setUserPassword($siteEntity->getUserPassword()); goto a3621; fe038: if (!(true === is_null($subdomain) || "\x77\x77\167" == $subdomain)) { goto F9c80; } goto ba8be; f6e41: $siteEntity = $this->siteEntityManager->createEntity(); goto ed058; c8ad3: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto D8cc6; B80b0: $pythonSiteCreator->resetPermissions(); goto A3fd6; cf48f: $pythonSettingsEntity->setPythonVersion($pythonVersion); goto d576d; f9965: return $siteEntity; goto d322f; d6c7c: $pythonSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto b2d26; Ac2a8: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto f9965; A8e52: C2d28: goto c7dd3; ba8be: if (true === isset($_ENV["\x41\120\x50\137\x48\x54\124\120\63"]) && "\164\x72\x75\x65" === $_ENV["\101\120\120\x5f\x48\x54\x54\x50\63"]) { goto c1971; } goto A5e88; da13b: $certificateEntity->setSite($siteEntity); goto f3ca9; E0b80: $pythonSite->setRegistrableDomain($registrableDomain); goto ef6ce; Bc36a: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto a5d39; c6084: $certificateEntity = $this->certificateEntityManager->createEntity(); goto da13b; A7386: $pythonSiteCreator->createNginxVhost(); goto bbcaa; bac04: $pythonSiteCreator->writePythonVersionFile(); goto af441; c7dd3: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto C6e1f; d02d7: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto F3984; F7f49: $constraintViolationList = new ConstraintViolationList(); goto D2689; c3ca4: $pythonSite->setUser($siteEntity->getUser()); goto E2c40; ed485: ccfa9: goto Bd4a4; f38b7: $pythonSite->setCertificate($certificateEntity); goto Fcbfc; fc89f: $siteEntity->setDomainName($domainName); goto ce519; b2d26: $pythonSiteCreator = new PythonSiteCreator($pythonSite); goto Cf256; Cafa3: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto Fdef2; daaf5: $subjectAlternativeNames = []; goto E7dfa; b7756: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto dec9d; A5e88: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\56\57\x2e\56\x2f\x2e\x2e\57\x72\145\x73\157\x75\162\x63\x65\x73\57\x6e\x67\x69\x6e\x78\57\166\x68\x6f\163\164\x5f\164\145\x6d\x70\x6c\141\x74\145\x2f\162\x65\144\x69\162\145\143\164"); goto Cfec3; dbc9e: $subdomain = false === empty($subdomain) ? $subdomain : null; goto d1fbb; B19d9: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto e6f0e; ce519: $siteEntity->setUser($siteUser); goto e4623; Cf256: $pythonSiteCreator->createUser(); goto Fe9cf; Fdef2: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto Bec4f; Bb712: $pythonSite->setRootDirectory($siteEntity->getRootDirectory()); goto f38b7; Da155: $pythonSettingsEntity->setSite($siteEntity); goto d9d90; Cf2d9: $siteEntity->setPythonSettings($pythonSettingsEntity); goto cf48f; ef6ce: $pythonSite->setSubdomain($subdomain); goto Bb712; fcd99: $siteEntity->setCertificate($certificateEntity); goto Ce755; Ce755: $pythonSite = new PythonSite(); goto c3ca4; Cfec3: goto C2d28; goto B224b; a3621: $pythonSite->setDomainName($domainName); goto E0b80; f846d: $csr = $csrGenerator->generate(); goto d28b5; D8100: $vhostTemplate->build(); goto c8ad3; Ee6e8: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto d2e16; E6f6b: $siteEntity->setVhostTemplate($vhostTemplate); goto f5f5b; d28b5: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto fa1ef; d322f: } private function createStaticSite(string $domainName, string $siteUser, string $siteUserPassword) : SiteEntity { goto Ca98d; efac3: $staticSiteCreator->createRootDirectory(); goto B8d23; Fed42: eb746: goto Cdd88; E3a5e: $constraintViolationList = new ConstraintViolationList(); goto cf8ab; Ef527: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto Baa2e; b0629: $certificateEntity = $this->certificateEntityManager->createEntity(); goto C4b70; Ae853: $subjectAlternativeNames = []; goto ffbab; A30a7: $vhostTemplate = new StaticVhostTemplate($staticSite); goto f4f05; C8621: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto Ccedf; d1eef: $staticSite->setRootDirectory($siteEntity->getRootDirectory()); goto aed9d; B8d23: $staticSiteCreator->createLogrotateFile(); goto e98a8; B3209: if (!(true === is_null($subdomain) || "\167\167\x77" == $subdomain)) { goto E9cdc; } goto D0873; Dcb98: $certificateEntity->setCertificate($selfSignedCertificate); goto cb88f; c98a0: $staticSite->setUserPassword($siteEntity->getUserPassword()); goto ba756; a3c54: $staticSiteCreator->reloadNginxService(); goto ad296; e89f2: $subdomain = $resolvedDomainName->subDomain()->toString(); goto E2d2e; E3d6e: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto d5f5e; adf4e: $vhostTemplate = sprintf("\45\163\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto F0bb9; b304b: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\56\x2f\56\56\x2f\x2e\56\x2f\162\x65\163\157\165\x72\143\x65\163\x2f\156\147\151\156\170\x2f\166\150\x6f\x73\x74\137\164\145\155\160\x6c\141\164\145\x2f\x72\145\144\151\162\145\x63\x74"); goto D23d8; f4f05: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto a23b5; ad296: $staticSiteCreator->resetPermissions(); goto A30a7; a24ab: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto B500d; aed9d: $staticSite->setCertificate($certificateEntity); goto f1992; C4b70: $certificateEntity->setSite($siteEntity); goto ec8d7; a0cad: $vhostTemplate->build(); goto Ef527; D3e84: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::STATIC_SITE_VHOST_TEMPLATE_NAME); goto F87fc; E8e68: da55c: goto F129a; d5f5e: $csr = $csrGenerator->generate(); goto C6680; e6ef5: $staticSiteCreator->createPrivateKeyAndCertificate(); goto a0d8f; d3e68: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto a0cad; cf706: $subjectAlternativeNames[] = $registrableDomain; goto Fed42; e3857: $siteEntity->setType(SiteEntity::TYPE_STATIC); goto d2382; ffbab: if (!(true === is_null($subdomain))) { goto da55c; } goto c482a; cf36b: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto Dcb98; Ce46b: dfcab: goto C8621; ed3a1: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto e89f2; dee0f: return $siteEntity; goto D9d05; ba756: $staticSite->setDomainName($domainName); goto d3276; Cdd88: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto E3d6e; fbfc9: $staticSite = new StaticSite(); goto eb53c; b0bdc: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\56\57\56\x2e\57\56\x2e\57\162\145\x73\x6f\x75\162\x63\145\163\x2f\156\147\151\x6e\x78\x2f\x76\150\x6f\x73\x74\137\x74\x65\155\x70\x6c\141\x74\x65\x2f\x72\145\144\x69\x72\x65\143\x74\x2d\150\x74\164\x70\x33"); goto Ce46b; Baa2e: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto cbea1; c32c0: $staticSiteCreator->createUser(); goto efac3; Ad48d: $staticSite->setSubdomain($subdomain); goto d1eef; A64b1: E9cdc: goto Ca9f6; Ccedf: if (!(false === empty($redirectionVhostTemplate))) { goto f7290; } goto adf4e; E7a73: $siteEntity->setUserPassword($siteUserPassword); goto F0cc8; e3ea1: $certificateEntity->setDefaultCertificate(true); goto a24ab; F87fc: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto A66c9; cb88f: $siteEntity->setCertificate($certificateEntity); goto fbfc9; A66c9: $siteEntity = $this->siteEntityManager->createEntity(); goto e3857; bc543: $staticSiteCreator = new StaticSiteCreator($staticSite); goto c32c0; ee469: $siteConstraints = $this->validator->validate($siteEntity); goto D3b5c; d9e1e: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto A562e; B500d: $certificateEntity->setCsr($csr); goto cf36b; d3276: $staticSite->setRegistrableDomain($registrableDomain); goto Ad48d; eb53c: $staticSite->setUser($siteEntity->getUser()); goto c98a0; E2d2e: $subdomain = false === empty($subdomain) ? $subdomain : null; goto D3e84; ec8d7: $rsaKeyGenerator = new RsaKeyGenerator(); goto C3025; f7fa6: C0c4b: goto b0629; D23d8: goto dfcab; goto Ee332; F0cc8: $siteEntity->setRootDirectory($domainName); goto B3209; A562e: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto d3e68; Df258: throw new \Exception(implode("\73\40", $errorMessages)); goto f7fa6; C3025: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto Ae853; cf8ab: $constraintViolationList->addAll($siteConstraints); goto F1563; a0d8f: $staticSiteCreator->createNginxVhost(); goto a3c54; Df06a: $siteEntity->setUser($siteUser); goto E7a73; C6680: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto e3ea1; f1992: $staticSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto bc543; Ca98d: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto ed3a1; a23b5: $vhostTemplate->resetProcessors(); goto d9e1e; d2382: $siteEntity->setDomainName($domainName); goto Df06a; F1563: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto Df258; F129a: if (!(false === is_null($subdomain) && "\167\167\x77" == $subdomain)) { goto eb746; } goto cf706; e98a8: $staticSiteCreator->createIndexHtml(); goto e6ef5; cbea1: $this->siteEntityManager->updateEntity($siteEntity); goto dee0f; Ee332: Ac984: goto b0bdc; c482a: $subjectAlternativeNames[] = sprintf("\x77\167\167\56\x25\x73", $domainName); goto E8e68; F0bb9: f7290: goto A64b1; Ca9f6: $siteEntity->setVhostTemplate($vhostTemplate); goto ee469; D3b5c: if (!count($siteConstraints)) { goto C0c4b; } goto E3a5e; D0873: if (true === isset($_ENV["\x41\120\x50\137\110\x54\124\120\63"]) && "\x74\162\165\x65" === $_ENV["\x41\120\120\x5f\x48\x54\124\120\63"]) { goto Ac984; } goto b304b; D9d05: } private function createReverseProxySite(string $domainName, string $reverseProxyUrl, string $siteUser, string $siteUserPassword) : SiteEntity { goto D3914; b6301: $constraintViolationList->addAll($siteConstraints); goto e129b; fbd0e: $reversProxySiteCreator->createPrivateKeyAndCertificate(); goto c6421; Cd7a6: $certificateEntity = $this->certificateEntityManager->createEntity(); goto e530e; e530e: $certificateEntity->setSite($siteEntity); goto B2b66; d9199: $siteEntity->setVhostTemplate($vhostTemplate); goto e8753; f0a2f: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto Fd340; F656f: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\56\x2f\56\x2e\x2f\x2e\56\x2f\162\145\163\157\165\162\143\145\x73\57\x6e\x67\x69\x6e\170\x2f\166\x68\x6f\x73\164\137\x74\x65\x6d\160\x6c\x61\164\x65\x2f\162\145\144\151\162\x65\143\164\x2d\150\x74\164\160\63"); goto Ed997; dc24f: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto b317f; f3cf4: ac0f7: goto d9199; B671f: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto a5077; Bd908: d9762: goto Cd7a6; F79dc: F4162: goto F656f; e8753: $siteConstraints = $this->validator->validate($siteEntity); goto Deeeb; D3a7f: $reversProxySiteCreator = new ReverseProxySiteCreator($reverseProxySite); goto ff41a; f2d7d: $this->siteEntityManager->updateEntity($siteEntity); goto cb198; D7a22: $reversProxySiteCreator->createLogrotateFile(); goto fbd0e; c2054: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto a1ba8; f61c5: C5da7: goto Ea53b; C4bef: if (!(true === is_null($subdomain) || "\x77\167\167" == $subdomain)) { goto ac0f7; } goto Dcb62; e129b: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto De191; a547d: $siteEntity->setRootDirectory($domainName); goto A720b; A720b: $siteEntity->setReverseProxyUrl($reverseProxyUrl); goto C4bef; ec83f: A0f7a: goto f3cf4; F4e5c: $reversProxySiteCreator->createRootDirectory(); goto D7a22; D3914: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto dc24f; Fd340: $siteEntity = $this->siteEntityManager->createEntity(); goto B83d2; df064: $reverseProxySite->setUser($siteEntity->getUser()); goto dfde8; f7545: $subdomain = false === empty($subdomain) ? $subdomain : null; goto Fb811; b4e97: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto bd126; d1a1a: $reverseProxySite->setVhostTemplate($siteEntity->getVhostTemplate()); goto D3a7f; Deeeb: if (!count($siteConstraints)) { goto d9762; } goto a6bc2; Ca604: $certificateEntity->setCertificate($selfSignedCertificate); goto Eaf0f; Eaf0f: $siteEntity->setCertificate($certificateEntity); goto b56e8; cd8ed: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\x2f\x2e\56\57\x2e\56\x2f\x72\x65\163\x6f\165\162\143\145\x73\x2f\156\x67\x69\156\x78\x2f\x76\150\x6f\x73\x74\137\164\145\155\x70\x6c\141\x74\x65\57\x72\145\144\151\162\145\x63\164"); goto ac9f1; Ef0f0: $reverseProxySite->setReverseProxyUrl($reverseProxyUrl); goto d1a1a; c9f6a: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto C64bc; fdee5: if (!(false === empty($redirectionVhostTemplate))) { goto A0f7a; } goto Cb094; A2785: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto B671f; ae744: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto Ca604; a5077: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto a7cb3; Af278: $subjectAlternativeNames[] = sprintf("\167\x77\167\x2e\45\163", $domainName); goto Ebb90; a1ba8: $vhostTemplate->resetProcessors(); goto A2785; b317f: $subdomain = $resolvedDomainName->subDomain()->toString(); goto f7545; cb198: return $siteEntity; goto Bb85e; B389a: $siteEntity->setDomainName($domainName); goto D12bd; B83d2: $siteEntity->setType(SiteEntity::TYPE_REVERSE_PROXY); goto B389a; b56e8: $reverseProxySite = new ReverseProxySite(); goto df064; c6421: $reversProxySiteCreator->createNginxVhost(); goto ce11a; bfdd8: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto Af0d9; C64bc: $certificateEntity->setDefaultCertificate(true); goto Fec15; fa26e: $reverseProxySite->setCertificate($certificateEntity); goto Ef0f0; ec4cd: $reverseProxySite->setRootDirectory($siteEntity->getRootDirectory()); goto fa26e; Ed997: Fcb17: goto bc060; Af0d9: $csr = $csrGenerator->generate(); goto c9f6a; c1c14: if (!(true === is_null($subdomain))) { goto e7bbe; } goto Af278; F186e: $reverseProxySite->setRegistrableDomain($registrableDomain); goto Ea8ee; a7cb3: $vhostTemplate->build(); goto b4e97; Dfca3: $vhostTemplate = new ReverseProxyVhostTemplate($reverseProxySite); goto c2054; ce11a: $reversProxySiteCreator->reloadNginxService(); goto Da7d5; D390b: if (!(false === is_null($subdomain) && "\x77\x77\167" == $subdomain)) { goto C5da7; } goto d9993; Ea53b: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto bfdd8; B8471: $reverseProxySite->setDomainName($domainName); goto F186e; Dcb62: if (true === isset($_ENV["\101\120\120\x5f\110\x54\x54\x50\x33"]) && "\x74\162\x75\145" === $_ENV["\x41\120\x50\137\110\x54\124\x50\x33"]) { goto F4162; } goto cd8ed; Cb094: $vhostTemplate = sprintf("\45\163\x25\x73", $redirectionVhostTemplate, $vhostTemplate); goto ec83f; Ea8ee: $reverseProxySite->setSubdomain($subdomain); goto ec4cd; ac9f1: goto Fcb17; goto F79dc; D12bd: $siteEntity->setUser($siteUser); goto E7a93; a6bc2: $constraintViolationList = new ConstraintViolationList(); goto b6301; d9993: $subjectAlternativeNames[] = $registrableDomain; goto f61c5; c6294: $certificateEntity->setCsr($csr); goto ae744; B2b66: $rsaKeyGenerator = new RsaKeyGenerator(); goto F7d63; Fec15: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto c6294; E7a93: $siteEntity->setUserPassword($siteUserPassword); goto a547d; bd126: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto f2d7d; Fcad2: $subjectAlternativeNames = []; goto c1c14; ff41a: $reversProxySiteCreator->createUser(); goto F4e5c; F7d63: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto Fcad2; De191: throw new \Exception(implode("\x3b\40", $errorMessages)); goto Bd908; Fb811: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::REVERSE_PROXY_VHOST_TEMPLATE_NAME); goto f0a2f; bc060: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto fdee5; Da7d5: $reversProxySiteCreator->resetPermissions(); goto Dfca3; Ebb90: e7bbe: goto D390b; dfde8: $reverseProxySite->setUserPassword($siteEntity->getUserPassword()); goto B8471; Bb85e: } public function installedWordPressSite(Request $request) : Response { goto de868; de868: $session = $request->getSession(); goto B6d91; d5bc4: c3f85: goto C606d; C606d: return $response; goto c8849; B6d91: $siteCredentials = $session->get("\x73\x69\164\x65\103\162\145\144\145\x6e\164\x69\x61\x6c\163"); goto C19e1; Be87d: $response = $this->render("\x46\162\157\x6e\164\145\x6e\x64\57\x53\151\x74\145\57\x4e\x65\167\57\167\x6f\162\x64\160\x72\x65\x73\163\x2d\x69\x6e\x73\164\141\154\154\x65\x64\x2e\x68\x74\155\154\x2e\x74\x77\x69\x67", ["\x73\151\x74\x65\103\162\145\144\145\x6e\x74\151\141\x6c\x73" => $siteCredentials]); goto e21e0; Da203: $response = $this->redirect($this->generateUrl("\x63\x6c\160\137\x73\x69\x74\145\x73")); goto A1991; e21e0: return $response; goto d5bc4; C19e1: if (false === empty($siteCredentials)) { goto fbfc5; } goto Da203; f49b1: $siteCredentials = $this->renderSiteCredentials($siteCredentials); goto Be87d; A1991: goto c3f85; goto E54b1; E54b1: fbfc5: goto f49b1; c8849: } private function renderSiteCredentials(array $siteCredentials) : string { goto C74e3; Ba8e2: foreach ($siteCredentials as $section => $sectionData) { goto B9a3a; ef02c: $renderedCredentials .= "\x2d\55\x2d\55\x2d\x2d\55\55\x2d\x2d\55\55\x2d\55\x2d\x2d\55\x2d\55\55\x2d\55\x2d\x2d\55\55\x2d\55\x2d\x2d\55\x2d\55\x2d\55\x2d\x2d\x2d\55\55\x2d\x2d\55\55\55\55\x2d\x2d\x2d\x2d\x2d\55\55\55" . PHP_EOL; goto c63d6; c63d6: foreach ($sectionData as $key => $value) { $renderedCredentials .= sprintf("\x25\x73\72\40\45\163", $key, $value) . PHP_EOL; Ef7e4: } goto c6974; c6974: A24f3: goto edbd1; edbd1: $renderedCredentials .= PHP_EOL; goto C442e; B9a3a: $renderedCredentials .= $section . PHP_EOL; goto ef02c; C442e: bf1cc: goto Afbcb; Afbcb: } goto Abfe8; f6df4: return $renderedCredentials; goto A3c99; C74e3: $renderedCredentials = ''; goto Ba8e2; Abfe8: Da437: goto f6df4; A3c99: } private function getVhostTemplateEntity(string $name) : mixed { goto e97f7; e4f51: return $vhostTemplateEntity; goto eb0fa; fc20e: throw new \Exception($this->translator->trans("\126\150\x6f\163\164\x20\124\x65\155\x70\154\141\164\x65\40\x25\x76\x68\x6f\x73\164\x54\145\155\x70\x6c\141\x74\145\x25\x20\x64\x6f\145\x73\40\156\157\x74\40\x65\170\151\163\x74\x2e", ["\x25\166\x68\157\163\x74\124\145\x6d\160\154\141\x74\x65\x25" => $name])); goto a6cc9; c64fc: if (!(true === is_null($vhostTemplateEntity))) { goto fd5f5; } goto fc20e; e97f7: $vhostTemplateEntity = $this->vhostTemplateEntityManager->findOneByName($name); goto c64fc; a6cc9: fd5f5: goto e4f51; eb0fa: } private function getConstraintViolationListErrorMessages(ConstraintViolationList $constraintViolationList) : array { goto c0b95; c832e: a8bfd: goto a8ec1; c0b95: $errorMessages = []; goto a5597; a5597: foreach ($constraintViolationList as $constraint) { $errorMessages[] = sprintf("\x25\x73\72\x20\45\x73", $constraint->getPropertyPath(), $constraint->getMessage()); C7af1: } goto c832e; a8ec1: return $errorMessages; goto ba055; ba055: } private function generateNameFromDomainName(string $domainName) : string { goto B304f; f5da8: if ("\167\167\167" == $subdomain) { goto ff4f7; } goto E065c; Aed7e: if (!(false === empty($subdomain))) { goto Bd686; } goto a2652; B304f: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto Ec6cb; a2652: $explodedSubdomain = explode("\x2e", $subdomain); goto d4464; E493b: $name = $explodedRegistrableDomain[0] ?? ''; goto E8d69; Ec0cc: Bd686: goto B6a38; E065c: $name = $explodedRegistrableDomain[0] ?? ''; goto Aed7e; E8d69: D9a07: goto d8bd3; d8bd3: return $name; goto a13b0; d4464: $name = sprintf("\45\x73\x2d\x25\163", $explodedRegistrableDomain[0] ?? '', implode("\55", $explodedSubdomain)); goto Ec0cc; C70b1: $subdomain = $resolvedDomainName->subDomain()->toString(); goto e589f; Ec6cb: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto C70b1; B6a38: goto D9a07; goto aa73d; e589f: $explodedRegistrableDomain = explode("\x2e", $registrableDomain); goto f5da8; aa73d: ff4f7: goto E493b; a13b0: } private function getUniqueDatabaseName(string $databaseName) : string { goto aee27; b8c84: $databaseExists = in_array($uniqueDatabaseName, $databases); goto Daed7; Eb9dd: $uniqueDatabaseName = sprintf("\x25\163\x2d\45\163", $databaseName, $i); goto B50ac; Fab0e: if (!(0 < $i)) { goto b1ef8; } goto Eb9dd; Fd232: $uniqueDatabaseName = sprintf("\45\163\x2d\144\x62", $uniqueDatabaseName); goto f7571; c86a3: b7183: goto Fa8d5; aee27: $uniqueDatabaseName = $databaseName; goto F8eaa; A490b: $databases = $databaseConnection->getDatabases(); goto f6871; B50ac: b1ef8: goto b8c84; f6871: e19dc: goto Fab0e; c2a69: if (true === $databaseExists) { goto e19dc; } goto c86a3; Edd8e: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto f5d45; Fa8d5: return $uniqueDatabaseName; goto C688a; F8eaa: if (!(strlen($uniqueDatabaseName) <= 3)) { goto A0e9d; } goto Fd232; f5d45: $databaseConnection = new DatabaseConnection($activeDatabaseServerEntity); goto A490b; Daed7: $i++; goto c2a69; ccfe7: $i = 0; goto Edd8e; f7571: A0e9d: goto ccfe7; C688a: } private function getUniqueDatabaseUserName(string $databaseUserName) : string { goto Cf3ce; C7acb: if (false === is_null($databaseUserEntity)) { goto Cdfe4; } goto f8ee9; c6ddd: E6d15: goto Faf2f; Faf2f: $i = 0; goto d484f; C187b: $uniqueDatabaseUserName = sprintf("\x25\x73\55\x64\x62", $uniqueDatabaseUserName); goto c6ddd; Cf3ce: $uniqueDatabaseUserName = $databaseUserName; goto C64fb; f21bb: return $uniqueDatabaseUserName; goto F0a73; ac164: $uniqueDatabaseUserName = sprintf("\x25\x73\x2d\x25\163", $databaseUserName, $i); goto d3091; C64fb: if (!(strlen($uniqueDatabaseUserName) <= 3)) { goto E6d15; } goto C187b; d3091: d054b: goto b6c5b; bee40: $uniqueDatabaseUserName = mb_substr($uniqueDatabaseUserName, 0, 32); goto f21bb; F20ab: if (!(0 < $i)) { goto d054b; } goto ac164; d484f: Cdfe4: goto F20ab; f8ee9: b041a: goto bee40; b6c5b: $databaseUserEntity = $this->databaseUserEntityManager->findOneByUserName($uniqueDatabaseUserName); goto bad67; bad67: $i++; goto C7acb; F0a73: } private function hasPermissions() : bool { goto Ba1a4; B25d2: D099f: goto B46a7; Ba1a4: $user = $this->getUser(); goto e66f1; e66f1: if (!(UserEntity::ROLE_USER != $user->getRole())) { goto D099f; } goto c1915; B46a7: return false; goto e5e4b; c1915: return true; goto B25d2; e5e4b: } }
